@@ -140,7 +140,13 @@ HoltWintersZZ  <- function (x,
 	if(trendtype!="N")
 		states <- cbind(states,b=final.fit$trend)
 	if(seasontype!="N")
-		states <- cbind(states,s=final.fit$season)
+  {
+    nr <- nrow(states)
+    nc <- ncol(states)
+    for(i in 1:m)
+  		states <- cbind(states,final.fit$season[(m-i)+(1:nr)])
+    colnames(states)[nc+(1:m)] <- paste("s",1:m,sep="")
+  }
 	states <- ts(states,frequency=m,start=tspx[1]-1/m)
 
 	# Package output as HoltWinters class
